@@ -1,5 +1,5 @@
 /*
- * Copyright 2005 - 2012  Zarafa B.V.
+ * Copyright 2005 - 2013  Zarafa B.V.
  * 
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU Affero General Public License, version 3, 
@@ -1043,7 +1043,7 @@ function collapseXML(xmlroot) {
 			var attributes = new Object;
 			if(node.attributes) {
 				for(var j=0;j<node.attributes.length;j++) {
-					attributes[node.attributes.item(j).nodeName] = node.attributes.item(j).firstChild.nodeValue;
+					attributes[node.attributes.item(j).name] = node.attributes.item(j).value;
 				}
 			}
 
