@@ -1,5 +1,5 @@
 /*
- * Copyright 2005 - 2012  Zarafa B.V.
+ * Copyright 2005 - 2013  Zarafa B.V.
  * 
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU Affero General Public License, version 3, 
@@ -214,6 +214,8 @@ WebClient.prototype.startClient = function()
 	 */
 	// if action attributes exist then process according to action type
 	var actionUrl = new String(window.location.search);
+	actionUrl = decodeURIComponent(actionUrl);
+
 	// check URL is fully encoded or just its data part is encoded
 	// we can't really tell the difference so we are using two different parameters for that
 	var urlIsDoubleEncoded = actionUrl.search(/\&url\=/i) != -1 ? true : false;
@@ -289,7 +291,7 @@ WebClient.prototype.handleURLAction = function (actionUrl)
 			for(var key in keyValuePairs) {
 				if(key != "action") {
 					// action attribute is not needed in creating createmail dialog URL
-					createmailUrl = createmailUrl + "&" + key + "=" + keyValuePairs[key];
+					createmailUrl = createmailUrl + "&" + encodeURIComponent(key) + "=" + encodeURIComponent(keyValuePairs[key]);
 				}
 			}
 
@@ -298,7 +300,7 @@ WebClient.prototype.handleURLAction = function (actionUrl)
 		}else if(keyValuePairs["action"] == "openmail") {
 
 			// open readmail dialog
-			var uri = DIALOG_URL+"task=readmail_standard&storeid=" + keyValuePairs["storeid"] + "&parententryid=" + keyValuePairs["parententryid"] + "&entryid=" + keyValuePairs["entryid"];
+			var uri = DIALOG_URL+"task=readmail_standard&storeid=" + encodeURIComponent(keyValuePairs["storeid"]) + "&parententryid=" + encodeURIComponent(keyValuePairs["parententryid"]) + "&entryid=" + encodeURIComponent(keyValuePairs["entryid"]);
 			webclient.openWindow(this, "openmail", uri);
 		}
 	}
@@ -367,7 +369,12 @@ WebClient.prototype.loadModule = function(moduleName, title, position, data, LAY
 WebClient.prototype.getModule = function(moduleID)
 {
 	var module = false;
-	
+
+	// sometimes modules are registered with objects but here we only need module id in form of string or number
+	if(typeof moduleID != 'string' && typeof moduleID != 'number') {
+		return module;
+	}
+
 	if(this.modules[moduleID]) {
 		module = this.modules[moduleID];
 	} else if(this.modules[this.modulePrefix + "_" + moduleID]) {
@@ -375,13 +382,21 @@ WebClient.prototype.getModule = function(moduleID)
 	}else {
 		// Loop through dialogs
 		for(var dialogname in this.dialogs){
-			if(this.dialogs[dialogname].window){
-				if(typeof this.dialogs[dialogname].window.webclient != "unknown" && typeof this.dialogs[dialogname].window.webclient == "object" && this.dialogs[dialogname].window.webclient != null){
-					module = this.dialogs[dialogname].window.webclient.getModule(moduleID);
-					if(module){
-						break;
+			var client = null;
+
+			try{ //try/catch in order to prevent IE from throwing an exception because of missing windows
+				if(this.dialogs[dialogname].window){
+					if(typeof this.dialogs[dialogname].window.webclient == "object" && this.dialogs[dialogname].window.webclient != null){
+						client = this.dialogs[dialogname].window.webclient;
 					}
 				}
+			} catch(e) {}
+
+			if(client !== null && client.getModule){
+				module = client.getModule(moduleID);
+				if(module){
+					break;
+				}
 			}
 		}
 	}
@@ -671,6 +686,7 @@ function eventWebClientUnload()
 	for(name in webclient.dialogs){
 		try{
 			webclient.dialogs[name].window.close();
+			delete webclient.dialogs[name];
 		}catch(e){
 		}
 	}
