@@ -1,6 +1,6 @@
 <?php
 /*
- * Copyright 2005 - 2012  Zarafa B.V.
+ * Copyright 2005 - 2013  Zarafa B.V.
  * 
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU Affero General Public License, version 3, 
@@ -90,7 +90,10 @@ function getJavaScript_onload(){ ?>
 					subtitle.appendChild(document.createTextNode("<?=get("subtitle", "", false, STRING_REGEX)?>" ));
 
 					var entryid = "<?=get("entryid", "none", false, ID_REGEX)?>";
-					if(entryid == "none" && typeof window.windowData != "undefined") {
+					if(entryid == '' ||  entryid == 'none' || entryid == 'undefined'){
+						entryid = false;
+					}
+					if(!entryid && typeof window.windowData != "undefined") {
 						entryid = window.windowData.entryid;
 					}
 
