@@ -1,5 +1,5 @@
 /*
- * Copyright 2005 - 2012  Zarafa B.V.
+ * Copyright 2005 - 2013  Zarafa B.V.
  * 
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU Affero General Public License, version 3, 
@@ -75,7 +75,7 @@ function preferences_loadSettings(settings){
 	}
 	
 	// theme
-	value = settings.get("global/theme_color", "white");
+	value = settings.get("global/theme_color", THEME_COLOR);
 	field = dhtml.getElementById("preferences_theme");
 	for(var i = 0; i<field.length; i++){
 		if (field.options[i].value == value){
@@ -208,6 +208,12 @@ function preferences_saveSettings(settings){
 	settings.set("global/previewpane",field.options[field.selectedIndex].value);
 	if (old_value != field.options[field.selectedIndex].value){
 		reloadNeeded = true;
+
+		// Remove all other previewpane settings
+		var folderData = settings.get('folders');
+		for(var i in folderData){
+			settings.deleteSetting('folders/'+i+'/previewpane');
+		}
 	}
 
 	// read receipt handling
