@@ -1,5 +1,5 @@
 /*
- * Copyright 2005 - 2012  Zarafa B.V.
+ * Copyright 2005 - 2013  Zarafa B.V.
  * 
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU Affero General Public License, version 3, 
@@ -75,9 +75,11 @@ function submitFolder() {
 		// for single selection
 		var selectedFolderId = module.selectedFolder;
 		
-		if(!module.selectedFolder)
+		if(!module.selectedFolder) {
+			alert(_("Please select a folder") + ".");
 			return;
-			
+		}
+		
 		var selectedFolderElement = dhtml.getElementById(selectedFolderId);
 		
 		var result = new Object;
