@@ -1,5 +1,5 @@
 /*
- * Copyright 2005 - 2012  Zarafa B.V.
+ * Copyright 2005 - 2013  Zarafa B.V.
  * 
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU Affero General Public License, version 3, 
@@ -509,7 +509,11 @@ ItemModule.prototype.setBody = function(message, isReply, isConcept, addAsText)
 			if(key == "body"){
 				content += data[key].value;
 			}else{
-				content += data[key].label + ":\t" + data[key].value.htmlEntities() + "\n";
+				if(usingHTMLEditor()){
+					content += data[key].label + ":\t" + data[key].value.htmlEntities() + "\n";
+				}else{
+					content += data[key].label + ":\t" + data[key].value + "\n";
+				}
 			}
 		}
 		if(html_body)
@@ -767,9 +771,11 @@ ItemModule.prototype.createMailTemplate= function(message, htmlFormat)
 {
 	var properties = getMailProperties();
 	var result = new Object;
+
 	for(var tagName in properties)
 	{
 		var xmlValue = dhtml.getXMLValue(message, tagName, -1);
+
 		if(xmlValue !== -1){
 			switch(tagName){
 				case "message_delivery_time":
@@ -845,7 +851,6 @@ ItemModule.prototype.createMailTemplate= function(message, htmlFormat)
 		}
 	}
 
-
 	return result;
 }
 
