@@ -1,6 +1,6 @@
 <?php
 /*
- * Copyright 2005 - 2012  Zarafa B.V.
+ * Copyright 2005 - 2013  Zarafa B.V.
  * 
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU Affero General Public License, version 3, 
@@ -103,12 +103,14 @@
 	require("server/core/constants.php");
 	require("server/core/class.conversion.php");
 	require("server/core/class.mapisession.php");
+	require("server/core/class.entryid.php");
 	
 	require("server/core/class.request.php");
 	require("server/core/class.settings.php");
 	require("server/core/class.language.php");
 
 	require("server/core/class.state.php");
+	require("server/core/class.attachmentstate.php");
 
 	require("server/core/class.pluginmanager.php");
 	require("server/core/class.plugin.php");
@@ -122,7 +124,7 @@
 		}
 		session_destroy();
 
-		header("Refresh: 0; url=index.php");
+		header("Location: index.php", true, 303);
 		exit;
 	}
 
@@ -187,14 +189,17 @@
 		$GLOBALS["language"]->setLanguage($lang);
 		if($_GET && array_key_exists("logon", $_GET)) {
 			$GLOBALS['PluginManager']->triggerHook("server.index.login.success");
-			if(isset($_POST) && isset($_POST["action_url"]) && $_POST["action_url"] != "") {
-				// if action attributes are passed in POST variable then append it to URL for
+			if(isset($_GET["action"]) && $_GET["action"] != "" ) {
+				$actionReqURI = getActionRequestURI();
+
+				// if action attributes are passed in GET variable then append it to URL for
 				// further processing
-				$url = "index.php" . $_POST["action_url"];
-				header("Refresh: 0; url=$url");
+				$url = "index.php" . $actionReqURI;
+
+				header("Location: $url", true, 303);
 				exit;
 			} else {
-				header("Refresh: 0; url=index.php");
+				header("Location: index.php", true, 303);
 				exit;
 			}
 		}
@@ -208,11 +213,6 @@
 		if ($_GET && array_key_exists("load", $_GET)) {
 
 			// Get Attachment data from state and put it into the $_SESSION
-			$attachment_state = new State('attachments');
-			$attachment_state->open();
-			$_SESSION['files'] = $attachment_state->read("files");
-			$_SESSION['deleteattachment'] = $attachment_state->read("deleteattachment");
-			$attachment_state->close();
 			switch ($_GET["load"]) {
 				case "translations.js":
 					$GLOBALS['PluginManager']->triggerHook("server.index.load.jstranslations.before");
@@ -226,14 +226,6 @@
 						$GLOBALS['PluginManager']->triggerHook("server.index.load.upload_attachment.before");
 						include("server/upload_attachment.php");
 						$GLOBALS['PluginManager']->triggerHook("server.index.load.upload_attachment.after");
-						// Get Attachment data from $_SESSION and put it into the state
-						// Do it now before outputting the dialog.php data, so that zarafa.php cannot be called
-						// before we have written the data
-						$attachment_state = new State('attachments');
-						$attachment_state->open();
-						$attachment_state->write("files", $_SESSION['files']);
-						$attachment_state->write("deleteattachment", $_SESSION['deleteattachment']);
-						$attachment_state->close();
 					}
 					$GLOBALS['PluginManager']->triggerHook("server.index.load.dialog.before");
 					include("client/dialog.php");
@@ -261,23 +253,14 @@
 					$GLOBALS['PluginManager']->triggerHook("server.index.load.main.after");
 					break;
 			}
-
-			// Get Attachment data from $_SESSION and put it into the state
-			$attachment_state = new State('attachments');
-			$attachment_state->open();
-			$attachment_state->write("files", $_SESSION['files']);
-			$attachment_state->write("deleteattachment", $_SESSION['deleteattachment']);
-			$attachment_state->close();
-			// Prevent the SESSION data to be stored elsewhere
-			unset($_SESSION['files'], $_SESSION['deleteattachment']);
-
 		} else {
 			// Clean up old state files in tmp/session/
 			$state = new State("index");
 			$state->clean();
 
-			// Clean up old attachments in tmp
-			cleanTemp(TMP_PATH, UPLOADED_ATTACHMENT_MAX_LIFETIME);
+			// Clean up old attachments in tmp/attachments/
+			$state = new AttachmentState();
+			$state->clean();
 					
 			// clean search folders
 			cleanSearchFolders();
