@@ -1,6 +1,6 @@
 <?php
 /*
- * Copyright 2005 - 2012  Zarafa B.V.
+ * Copyright 2005 - 2013  Zarafa B.V.
  * 
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU Affero General Public License, version 3, 
@@ -72,7 +72,9 @@
 				switch($type){
 					case("add"):
 						//get info from MAPI
-						$userData = $this->getUserData(utf8_to_windows1252($selUser["username"]), $selUser["clientuser"] == "c_user" ? true : false);
+						//search the user info on the emailaddress bases 
+						$query = $selUser["emailaddress"] ? $selUser["emailaddress"] : $selUser["username"];
+						$userData = $this->getUserData(u2w($query), $selUser["clientuser"] == "c_user" ? true : false);
 
 						if($userData){
 							$data = array();
@@ -132,7 +134,7 @@
 							$user["username"] = $selUser["username"];
 							$user["entryid"] = $selUser["username"];
 							$user["fullname"] = $selUser["username"];
-							$user["email"] = $selUser["username"];
+							$user["email"] = $selUser["emailaddress"] ? w2u($selUser["emailaddress"]) : $selUser["username"];
 
 							//add busy time
 							$busy = array();
@@ -177,6 +179,7 @@
 			
 			// First, try an exact-name lookup of the user
 			$rows = mapi_ab_resolvename($ab, array ( array(PR_DISPLAY_NAME => $query) ) , EMS_AB_ADDRESS_LOOKUP );
+
 			if(!$rows) {
 				// Next, try a loose lookup of the user
 				$rows = mapi_ab_resolvename($ab, array ( array(PR_DISPLAY_NAME => $query) ), 0 );
@@ -234,7 +237,6 @@
 			if (is_array($rows) && count($rows)>0) {
 				$abitem = mapi_ab_openentry($ab, $rows[0][PR_ENTRYID]);
 				$user_data = mapi_getprops($abitem, array(PR_ACCOUNT, PR_DISPLAY_NAME, PR_DISPLAY_TYPE_EX, PR_ENTRYID, PR_EMAIL_ADDRESS, PR_SMTP_ADDRESS, PR_OBJECT_TYPE));
-				
 				$result = array();
 				$result["entryid"] = $user_data[PR_ENTRYID];
 				$result["username"] = windows1252_to_utf8($user_data[PR_ACCOUNT]);
@@ -268,7 +270,6 @@
 				}
 				$result["nameid"] = $query;
 			}
-			
 			return $result;
 		}
 		
