@@ -1,6 +1,6 @@
 <?php
 /*
- * Copyright 2005 - 2012  Zarafa B.V.
+ * Copyright 2005 - 2013  Zarafa B.V.
  * 
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU Affero General Public License, version 3, 
@@ -121,6 +121,54 @@
 		return $modules;
 	}
 	
+	/**
+	 * Will extract a specific list of arguments from the $_GET object and construct a properly 
+	 * (raw)urlencoded REQUEST_URI to be used for appending to an URL. 
+	 * A token can be supplied to change the first character. By default it will set an ? as the 
+	 * first character to directly append it to an URL. When other arguments preceed this string it 
+	 * can be changed to an & or to any other value, including to no character by supplying an empty
+	 * string.
+	 * @param String $token (Optional) First character of the returned string. Defaults to "?".
+	 * @return String The REQUEST URI containing the values from the specific list of $_GET-arguments.
+	 */
+	function getActionRequestURI($token = '?'){
+		$requestURI = '';
+		$allowedArgs = Array(
+			'action', 
+			'url', 
+			'to', 
+			'cc', 
+			'bcc', 
+			'storeid', 
+			'parententryid', 
+			'entryid', 
+			'message_action', 
+			'subject', 
+			'body');
+
+		$urlArgs = Array();
+		if($_GET){
+			// Put all allowed arguments in a key/value list
+			for($i=0,$len=count($allowedArgs);$i<$len;$i++){
+				$argName = $allowedArgs[$i];
+				if(isset($_GET[ $argName ])){
+					$urlArgs[ $argName ] = $_GET[ $argName ];
+				}
+			}
+
+			// Create the correctly encoded string for each argument that was extracted \
+			$formattedArgsList = Array();
+			foreach($urlArgs as $argName => $argValue){
+				$formattedArgsList[] = rawurlencode($argName) . '=' . rawurlencode($argValue);
+			}
+
+			// Put them together and ... DONE!
+			$requestURI = $token . implode('&', $formattedArgsList);
+		}
+ 		return $requestURI;
+	}
+
+
 	/**
 	 * Function which replaces some characters to correct XML values.
 	 * @param string @string string which should be converted
@@ -354,26 +402,61 @@
 	 * Cleans up the temp directory.
 	 * @param String $directory The path to the temp dir or sessions dir.
 	 * @param Integer $maxLifeTime The maximum allowed age of files in seconds.
+	 * @param Boolean $recursive False to prevent the folder to be cleaned up recursively
+	 * @param Boolean $removeSubs False to prevent empty subfolders from being deleted
+	 * @return Boolean True if the folder is empty
 	 */
-	function cleanTemp($directory = TMP_PATH, $maxLifeTime = false)
+	function cleanTemp($directory = TMP_PATH, $maxLifeTime = STATE_FILE_MAX_LIFETIME, $recursive = true, $removeSubs = true)
 	{
-		if($maxLifeTime===false)$maxLifeTime = ini_get("session.gc_maxlifetime");
-
-		if (!is_dir($directory)){
+		if (!is_dir($directory)) {
 			return;
 		}
 
+		// PHP doesn't do this by itself, so before running through
+		// the folder, we should flush the statcache, so the 'atime'
+		// is current.
+		clearstatcache();
+
 		$dir = opendir($directory);
+		$is_empty = true;
 
-		while($file = readdir($dir)) {
-			if (!is_dir($directory . "/" . $file)){
-				$fileinfo = stat($directory . "/" . $file);
+		while ($file = readdir($dir)) {
+			// Skip special folders
+			if ($file === '.' || $file === '..') {
+				continue;
+			}
 
-				if($fileinfo && $fileinfo["atime"] < time() - $maxLifeTime) {
-					unlink($directory . "/" . $file);
+			$path = $directory . DIRECTORY_SEPARATOR . $file;
+
+			if (is_dir($path)) {
+				// If it is a directory, check if we need to
+				// recursively clean this subfolder.
+				if ($recursive) {
+					// If cleanTemp indicates the subfolder is empty,
+					// and $removeSubs is true, we must delete the subfolder
+					// otherwise the currently folder is not empty.
+					if (cleanTemp($path, $maxLifeTime, $recursive) && $removeSubs) {
+						rmdir($path);
+					} else {
+						$is_empty = false;
+					}
+				} else {
+					// We are not cleaning recursively, the current
+					// folder is not empty.
+					$is_empty = false;
+				}
+			} else {
+				$fileinfo = stat($path);
+
+				if ($fileinfo && $fileinfo["atime"] < time() - $maxLifeTime) {
+					unlink($path);
+				} else {
+					$is_empty = false;
 				}
 			}
 		}
+
+		return $is_empty;
 	}
 
 	function cleanSearchFolders()
